package gui;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import util.DatabaseUtil;

public class LoginFrame extends JFrame {
    private JComboBox<String> userTypeComboBox;
    private JTextField idField;
    private JPasswordField passwordField;
    private JButton loginButton;

    public LoginFrame() {
        setTitle("登录");
        setSize(300, 200);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);

        JPanel panel = new JPanel();
        panel.setLayout(new GridLayout(4, 2));

        panel.add(new JLabel("用户类型:"));
        userTypeComboBox = new JComboBox<>(new String[]{"学生", "教师"});
        panel.add(userTypeComboBox);

        panel.add(new JLabel("ID:"));
        idField = new JTextField();
        panel.add(idField);

        panel.add(new JLabel("密码:"));
        passwordField = new JPasswordField();
        panel.add(passwordField);

        loginButton = new JButton("登录");
        panel.add(loginButton);

        loginButton.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                handleLogin();
            }
        });

        add(panel);
    }

    private void handleLogin() {
        String userType = (String) userTypeComboBox.getSelectedItem();
        String id = idField.getText();
        String password = new String(passwordField.getPassword());

        String tableName = "学生".equals(userType) ? "students" : "teachers";
        String idColumnName = "学生".equals(userType) ? "student_id" : "teacher_id";
        String sql = "SELECT * FROM " + tableName + " WHERE " + idColumnName + " = ? AND password = ?";

        try (Connection conn = DatabaseUtil.getConnection();
             PreparedStatement stmt = conn.prepareStatement(sql)) {

            stmt.setString(1, id);
            stmt.setString(2, password);

            ResultSet rs = stmt.executeQuery();

            if (rs.next()) {
                if ("教师".equals(userType)) {
                    TeacherMainFrame teacherMainFrame = new TeacherMainFrame();
                    teacherMainFrame.setVisible(true);
                } else {
                    // TODO: 打开学生主界面
                    JOptionPane.showMessageDialog(this, "学生登录成功！", "提示", JOptionPane.INFORMATION_MESSAGE);
                }
                dispose();
            } else {
                JOptionPane.showMessageDialog(this, "无效的ID或密码", "错误", JOptionPane.ERROR_MESSAGE);
            }
        } catch (SQLException e) {
            e.printStackTrace();
            JOptionPane.showMessageDialog(this, "数据库错误：" + e.getMessage(), "错误", JOptionPane.ERROR_MESSAGE);
        }
    }

    public static void main(String[] args) {
        SwingUtilities.invokeLater(() -> {
            LoginFrame loginFrame = new LoginFrame();
            loginFrame.setVisible(true);
        });
    }
}
